@@ -14,7 +14,7 @@ Usage::
     client: DynamoDBStreamsClient = boto3.client("dynamodbstreams")
     session_client: DynamoDBStreamsClient = session.client("dynamodbstreams")
 """
-from mypy_boto3_dynamodbstreams.client import DynamoDBStreamsClient as Client, DynamoDBStreamsClient
+from mypy_boto3_dynamodbstreams.client import DynamoDBStreamsClient, DynamoDBStreamsClient as Client
 
 
 __all__ = ("Client", "DynamoDBStreamsClient")
